Type

Enum Type 

pub enum Type {
Show 14 variants ResolvedPath { path: Path, is_generic: bool, }, DynTrait(Vec<PolyTrait>, Option<Lifetime>), Generic(String), Primitive(PrimitiveType), BareFunction(Box<BareFunctionDecl>), Tuple(Vec<Type>), Slice(Box<Type>), Array(Box<Type>, String), Never, RawPointer(Mutability, Box<Type>), BorrowedRef { lifetime: Option<Lifetime>, mutability: Mutability, type_: Box<Type>, }, QPath { name: String, self_type: Box<Type>, trait_: Box<Type>, }, Infer, ImplTrait(Vec<GenericBound>),
}
A representation of a type suitable for hyperlinking purposes. Ideally, one can get the original type out of the AST/TyCtxt given one of these, if more information is needed. Most importantly, it does not preserve mutability or boxes.

Variants



ResolvedPath

Structs/enums/traits (most that would be an hir::TyKind::Path).

Fields

path: Path
is_generic: bool

true if is a T::Name path for associated types.



DynTrait(Vec<PolyTrait>, Option<Lifetime>)

dyn for<'a> Trait<'a> + Send + 'static



Generic(String)

For parameterized types, so the consumer of the JSON don’t go looking for types which don’t exist anywhere.



Primitive(PrimitiveType)

Primitives are the fixed-size numeric types (plus int/usize/float), char, arrays, slices, and tuples.



BareFunction(Box<BareFunctionDecl>)

extern "ABI" fn



Tuple(Vec<Type>)



Slice(Box<Type>)



Array(Box<Type>, String)

The String field is about the size or the constant representing the array’s length.



Never



RawPointer(Mutability, Box<Type>)



BorrowedRef

Fields

lifetime: Option<Lifetime>
mutability: Mutability
type_: Box<Type>


QPath

Fields

name: String
self_type: Box<Type>
trait_: Box<Type>


Infer



ImplTrait(Vec<GenericBound>)